@@ -182,9 +182,9 @@ fi
 
 # Install pm-utils hook only if pm-utils config dir is present, or force the
 # install if we have a DESTDIR.
-if [ -n "$DESTDIR" -o -d "$DESTDIR/etc/pm/sleep.d" ] ; then
-	if ( ! $INSTALL -m 755 etc/pm/sleep.d/99laptop-mode "$DESTDIR/etc/pm/sleep.d" ) ; then
-		echo "$0: Failed to install 99-laptop-mode into /etc/pm/sleep.d. Installation failed."
+if [ -n "$DESTDIR" -o -d "$DESTDIR/usr/lib/pm-utils/sleep.d" ] ; then
+	if ( ! $INSTALL -D -m 755 usr/lib/pm-utils/sleep.d/99laptop-mode "$DESTDIR/usr/lib/pm-utils/sleep.d/99laptop-mode" ) ; then
+		echo "$0: Failed to install 99-laptop-mode into /usr/lib/pm-utils/sleep.d. Installation failed."
 		exit 36
 	fi
 fi
@@ -316,6 +316,31 @@ if [ "$INIT_D" != "none" ] ; then
 			exit 24
 		fi
 	fi
+
+    # Check for acpid and restart if running
+    acpi_pid=`pidof acpid`
+    if [ ! -z $acpi_pid ]; then
+        echo "Reloading acpid daemon"
+        killall -SIGHUP acpid;
+    fi
+
+    apm_pid=`pidof apmd`
+    if [ ! -z $apm_pid ]; then
+        echo "Reloading apmd daemon"
+        killall -SIGHUP apmd;
+    fi
+
+    pbbuttonsd_pid=`pidof pbbuttonsd`
+    if [ ! -z $pbbuttonsd_pid ]; then
+        echo "Reloading pbbuttonsd daemon"
+        killall -SIGHUP pbbuttonsd;
+    fi
+
+    pmud_pid=`pidof pmud`
+    if [ ! -z $pmud_pid ]; then
+        echo "Reloading pmud daemon"
+        killall -SIGHUP pmud;
+    fi
 fi
 
 echo "Installation complete."
